@@ -262,6 +262,7 @@ def makeEvent(eventInfo, old_id):
     """Makes a new alarmd event"""
     #make new event with timestamp and title
     event = alarm.Event()
+    event.message = eventInfo["title"]
     try:
         event.alarm_time = eventInfo["ttime"]
         dt = datetime.datetime.fromtimestamp(eventInfo["ttime"])
@@ -271,7 +272,7 @@ def makeEvent(eventInfo, old_id):
     t = loadFieldsDict()["types"]
     #set action depending on type
     if eventInfo["type"] == t["alarm_type"]:
-        action_stop, action_snooze = event.add_actions(2)
+        action_snooze, action_stop = event.add_actions(2)
         action_stop.flags |= (alarm.ACTION_WHEN_RESPONDED |
                               alarm.ACTION_TYPE_NOP)
         action_stop.label = 'Stop'
